@@ -201,9 +201,9 @@ def fpnd(
 
     ``jets`` are passed through our pretrained ParticleNet module and activations are compared
     with the cached activations from real jets.
-    The recommended and max number of jets is 50,000
+    The recommended and max number of jets is 50,000.
 
-    **torch_geometric must be installed separately for running inference with ParticleNet**
+    **torch_geometric must be installed separately for running inference with ParticleNet.**
 
     Currently FPND only supported for the JetNet dataset with 30 particles, but functionality for
     other datasets + ability for users to use their own version is in development.
@@ -612,9 +612,8 @@ def cov_mmd(
         real_rand_sample = real_jets[real_rand]
         gen_rand_sample = gen_jets[gen_rand]
 
-        dists = emds(
-            gen_rand_sample, real_rand_sample
-        )  # 2D array of emds, with shape (len(gen_rand_sample), len(real_rand_sample))
+        # 2D array of emds, with shape (len(gen_rand_sample), len(real_rand_sample))
+        dists = emds(gen_rand_sample, real_rand_sample)
 
         # for MMD, for each gen jet find the closest real jet and average EMDs
         mmds.append(np.mean(np.min(dists, axis=0)))
